.. _tutor_lib_network:

=======
Network
=======

Network library provides clients/API for many network protocols and technologies.

* Database: client for databases: SQLite, Oracle, MySQL, PostgreSQL, JDBC
* Email: client for protocols: SMTP, POP, IMAP
* FTP: client for protocols: FTP/FTP, SFTP, TFTP
* INET: client for protocols: IP, TCP, UDP
* Java: bridge to Java VM which enables interaction with Java code  
* JMS: client for protocols: JMS, STOMP, AMQP
* LDAP: client for LDAP protocol
* REST: client for HTTP/HTTPS protocol
* RPC: client for Java RMI technology
* Selenium: bridge to Selenium API for web GUI interaction
* SOAP: client for SOAP protocol
* Terminal: client for SSH protocol

.. toctree::
   :maxdepth: 1

   tut1_dbi
   tut2_email
   tut3_ftp
   tut4_inet
   tut5_java
   tut6_jms
   tut7_ldap
   tut8_rest
   tut9_rpc
   tut10_selen
   tut11_soap
   tut12_term